@@ -15,9 +15,9 @@ BEGIN {
   $Dist::Zilla::Plugin::Test::Compile::AUTHORITY = 'cpan:JQUELIN';
 }
 {
-  $Dist::Zilla::Plugin::Test::Compile::VERSION = '2.035';
+  $Dist::Zilla::Plugin::Test::Compile::VERSION = '2.036';
 }
-# git description: v2.034-5-gf838562
+# git description: v2.035-4-ga257579
 
 # ABSTRACT: common tests to check syntax of your modules, only using core modules
 
@@ -53,9 +53,19 @@ has fake_home     => ( is=>'ro', isa=>'Bool', default=>0 );
 has needs_display => ( is=>'ro', isa=>'Bool', default=>0 );
 has fail_on_warning => ( is=>'ro', isa=>enum([qw(none author all)]), default=>'author' );
 has bail_out_on_fail => ( is=>'ro', isa=>'Bool', default=>0 );
+has xt_mode => ( is=>'ro', isa=>'Bool', default=>0 );
 
-has filename => ( is => 'ro', isa => 'Str', default => 't/00-compile.t' );
-has phase => ( is => 'ro', isa => 'Str', default => 'test' );
+has filename => (
+    is => 'ro', isa => 'Str',
+    lazy => 1,
+    default => sub { return ($_[0]->xt_mode ? 'xt/author' : 't') . '/00-compile.t' },
+);
+
+has phase => (
+    is => 'ro', isa => 'Str',
+    lazy => 1,
+    default => sub { return $_[0]->xt_mode ? 'develop' : 'test' },
+);
 
 sub mvp_multivalue_args { qw(skips) }
 sub mvp_aliases { return { skip => 'skips' } }
@@ -174,6 +184,7 @@ sub munge_file
                 needs_display => \($self->needs_display),
                 bail_out_on_fail => \($self->bail_out_on_fail),
                 fail_on_warning => \($self->fail_on_warning),
+                xt_mode => \($self->xt_mode),
             }
         )
     );
@@ -198,7 +209,7 @@ Dist::Zilla::Plugin::Test::Compile - common tests to check syntax of your module
 
 =head1 VERSION
 
-version 2.035
+version 2.036
 
 =head1 SYNOPSIS
 
@@ -290,6 +301,12 @@ Just like C<module_finder>, but for finding scripts.  The default value is
 C<:ExecFiles> (see also L<Dist::Zilla::Plugin::ExecDir>, to make sure these
 files are properly marked as executables for the installer).
 
+=item * C<xt_mode>
+
+When true, the default C<filename> becomes F<xt/author/00-compile.t> and the
+default C<dependency> phase becomes C<develop>. The test is adjusted to
+run against F<lib> instead of F<blib>.
+
 =back
 
 =head1 SEE ALSO
@@ -431,6 +448,8 @@ CODE
     : '# no fake home requested';
 }}
 
+my $inc_switch = q[{{ $xt_mode ? '-Ilib' : '-Mblib' }}];
+
 use File::Spec;
 use IPC::Open3;
 use IO::Handle;
@@ -442,7 +461,7 @@ for my $lib (@module_files)
     open my $stdin, '<', File::Spec->devnull or die "can't open devnull: $!";
     my $stderr = IO::Handle->new;
 
-    my $pid = open3($stdin, '>&STDERR', $stderr, $^X, '-Mblib', '-e', "require q[$lib]");
+    my $pid = open3($stdin, '>&STDERR', $stderr, $^X, $inc_switch, '-e', "require q[$lib]");
     binmode $stderr, ':crlf' if $^O eq 'MSWin32';
     my @_warnings = <$stderr>;
     waitpid($pid, 0);
